/*!
 * \file docmain.hpp
 * \brief This file contains documentation for Doxygen and does not have any significance with respect to C++.
 * \author F. Palacios
 * \version 6.2.0 "Falcon"
 *
 * The current SU2 release has been coordinated by the
 * SU2 International Developers Society <www.su2devsociety.org>
 * with selected contributions from the open-source community.
 *  - Prof. Juan J. Alonso's group at Stanford University.
 *  - Prof. Piero Colonna's group at Delft University of Technology.
 *  - Prof. Nicolas R. Gauger's group at Kaiserslautern University of Technology.
 *  - Prof. Alberto Guardone's group at Polytechnic University of Milan.
 *  - Prof. Rafael Palacios' group at Imperial College London.
 *  - Prof. Edwin van der Weide's group at the University of Twente.
 *  - Prof. Vincent Terrapon's group at the University of Liege.
 *
 * Copyright 2012-2019, Francisco D. Palacios, Thomas D. Economon,
 *                      Tim Albring, and the SU2 contributors.
 *
 * SU2 is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * SU2 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with SU2. If not, see <http://www.gnu.org/licenses/>.
 */

/*! 
 * \mainpage SU2 version 6.2.0 "Falcon"
 * SU2 suite is an open-source collection of C++ based software tools
 * to perform PDE analysis and PDE constrained optimization problems.  The toolset is designed with 
 * computational fluid dynamics and aerodynamic shape optimization in mind, but is extensible to
 * include other families of governing equations such as potential flow, electrodynamics, chemically reacting
 * flows, and many others.  SU2 is released under an
 * open-source license.
 * 
 * The following technical documentation describes the structure and details of the source code for developers. 
 */

/*!
 * \defgroup Config Descriptions of Configuration Options.
 * \brief Group of variables that can be set using the configuration file.
 */

/*!
 * \defgroup ConvDiscr Discretization of the convective terms.
 * \brief Group of classes which define the numerical methods for 
 *		  discretizing the convective terms of a Partial Differential Equation. 
 *		  There are methods for solving the direct, adjoint and linearized 
 *		  systems of equations.
 */

/*!
 * \defgroup ViscDiscr Discretization of the viscous terms.
 * \brief Group of classes which define the numerical methods for 
 *		  discretizing the viscous terms of a Partial Differential Equation. 
 *		  There are methods for solving the direct, adjoint and linearized 
 *		  systems of equations.
 */

/*!
 * \defgroup SourceDiscr Discretization of the source terms.
 * \brief Group of classes which define the numerical methods for 
 *		  discretizing the source terms of a Partial Differential Equation. 
 *		  There are methods for solving the direct, adjoint and linearized 
 *		  systems of equations.
 */

/*!
 * \defgroup Potential_Flow_Equation Solving the potential flow equation.
 * \brief Group of classes which define the system of Potential flow equation in 
 *		  three formulations: direct, adjoint, and linearized.
 */

/*!
 * \defgroup Euler_Equations Solving the Euler's equations.
 * \brief Group of classes which define the system of Euler equations in 
 *		  three formulations: direct, adjoint, and linearized.
 */

/*!
 * \defgroup Navier_Stokes_Equations Solving the Navier-Stokes' equations.
 * \brief Group of classes which define the system of Navier-Stokes equations in 
 *		  three formulations: direct, adjoint, and linearized.
 */

/*!
 * \defgroup Turbulence_Model Solving the turbulence models.
 * \brief Group of classes which define the turbulence model in 
 *		  three formulations: direct, adjoint, and linearized.
 */
